ArbParser class

Constructors

ArbParser([bool addName = false])

Properties

addName → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getHash(Map<String, dynamic> arb) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseMessage(Map<String, dynamic> arb, String messageKey, String debugString) → MessageWithMetadata
parseMessageFile(Map<String, dynamic> arb, AssetId assetId, [String inferredLocale = 'en_US']) → MessagesWithMetadata
parsePlaceholderMetadata(Map<String, dynamic> placeholders) → List<Placeholder>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited