BuildStepGenerator class

Constructors

BuildStepGenerator(BuildStep buildStep, GenerationOptions options)

Properties

buildStep → BuildStep
final
hashCode → int
The hash code for this object.
no setterinherited
inputId → AssetId
no setter
options → GenerationOptions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serializer → Serializer
no setter

Methods

build() → Future<void>
getParsedMessageFiles() → Future<List<MessagesWithMetadata>>
getSerializer(GenerationOptions generationOptions) → Serializer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseMessageFile(AssetId assetId) → Future<MessagesWithMetadata>
printIncludeFilesNotification(String? context, Map<String, ({String hasch, String path})> localeToResource) → void
Display a notification to the user to include the newly generated files in their assets.
reduce(MessagesWithMetadata parentFile, MessagesWithMetadata inputMessageFile) → MessagesWithMetadata
Only keep the messages which are in the parent file, as only those will get a generated method to embed them in code.
toString() → String
A string representation of this object.
inherited
writeDartLibrary(List<MessagesWithMetadata> assetList, MessagesWithMetadata messageList) → Future<void>
Generates the Dart library which extracts the messages from their file format and makes the available to the user in a way specified through the GenerationOptions.
writeDataFile(MessagesWithMetadata messages) → Future<void>
This writes the file containing the messages, which can be either a binary .carb file or a JSON file, depending on the serializer.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getParentFile(List<MessagesWithMetadata> arbResources, MessagesWithMetadata arb) → MessagesWithMetadata
Either get the referenced parent file, or try to infer which it might be.