ClassGeneration class

Inheritance

Constructors

ClassGeneration(GenerationOptions options, List<MessageWithMetadata> messages, String? context, List<Constructor> constructors, List<Field> fields, List<Method> methods)

Properties

constructors → List<Constructor>
final
context → String?
final
fields → List<Field>
final
hashCode → int
The hash code for this object.
no setterinherited
messages → List<MessageWithMetadata>
final
methods → List<Method>
final
options → GenerationOptions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() → List<Spec>
override
getClassName(String? context) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited