LibraryGeneration class

Inheritance

Constructors

LibraryGeneration(GenerationOptions options, String? context, String locale, List<MessageWithMetadata> messages, Map<String, ({String hasch, String path})> localeToResourceInfo)

Properties

context → String?
final
hashCode → int
The hash code for this object.
no setterinherited
locale → String
final
localeToResourceInfo → Map<String, ({String hasch, String path})>
final
messages → List<MessageWithMetadata>
final
options → GenerationOptions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() → List<Library>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited