MethodGeneration class

Inheritance

Constructors

MethodGeneration(GenerationOptions options, String? context, List<MessageWithMetadata> messages)

Properties

context → String?
final
hashCode → int
The hash code for this object.
no setterinherited
messages → List<MessageWithMetadata>
final
options → GenerationOptions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() → List<Method>
override
generateMessageCall(int index, MessageWithMetadata message) → Method?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pluralSelectorBody() → Code
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited