GenerationOptions class

Options for the message data file and code generation.

Constructors

GenerationOptions({required SerializationType serialization, required DeserializationType deserialization, required bool messageCalls, required bool findById, required IndexType indexType, required String header, required PluralSelectorType pluralSelector})

Properties

deserialization → DeserializationType
The data file deserialization, either through browser functionalities or dart native code.
final
findById → bool
Whether to generate a method to fetch a message by its id. Leads to the ids being stored in the data file.
final
hashCode → int
The hash code for this object.
no setterinherited
The header to add to all generated files, for example for licensing.
final
indexType → IndexType
How the messages should be indexed, either through ints or an enum
final
messageCalls → bool
Whether to generate named message calls. Example: An arb file like this
final
pluralSelector → PluralSelectorType
The origin of the algorithm for determining which plural case to use.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialization → SerializationType
The data file serialization, either json or (TBD) binary.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromPubspec(BuildStep buildStep) → Future<GenerationOptions>