Parser class

Constructors

Parser(String messageId, String filename, String messageString)

Properties

filename → String
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → String
final
messageString → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terminalTypeToString → Map<ST, String>
final

Methods

checkExtraRules(Node syntaxTree) → void
compress(Node syntaxTree) → Node
lexIntoTokens() → List<Node>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() → Node
parseIntoTree() → Node
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

indentForError(int position) → String