MessagesWithMetadata class

Constructors

MessagesWithMetadata(List<MessageWithMetadata> messages, String locale, String? context, String? referencePath, String hash, bool hasMetadata, AssetId assetId)

Properties

assetId → AssetId
final
context → String?
final
hash → String
final
hashCode → int
The hash code for this object.
no setterinherited
hasMetadata → bool
final
locale → String
final
messages → List<MessageWithMetadata>
final
referencePath → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<MessageWithMetadata>? messages, String? locale, String? context, String? referencePath, String? hash, bool? hasMetadata, AssetId? assetId}) → MessagesWithMetadata
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited